%% 
%% This is file 'format170x240multiauthor.cls'
%% 
\NeedsTeXFormat{LaTeX2e}\relax
\ProvidesClass{format170x240multiauthor}[2006/04/02 v0.2b Wiley-VCH Verlag GmbH \& Co. KGaA]
\LoadClass[%
            twoside,
            a4paper,
            smallheadings,
            parindent,
            10pt
          ]{scrbook}
%%  Fonts  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% to avoid overfull lines
\tolerance=400
\emergencystretch=5pt

\def\tocnumwidth{12mm}
\setlength\paperheight{240mm}
\setlength\paperwidth{170mm}

\renewcommand{\figurename}{Fig.}
\renewcommand{\tablename}{Tab.}
\providecommand{\definitionname}{Definition}
\providecommand{\theoremname}{Theorem}
\providecommand{\lemmaname}{Lemma}
\providecommand{\proofname}{Proof}
\providecommand{\prefacename}{Preface}
% preface chapter
\def\preface{\chapter*{\prefacename}
\markboth{\prefacename}{\prefacename}\copyrightzeile
  \addtocontents{toc}{%
    \protect\tocline
      {0}%
      {}%
      {\prefacename}%
      {\sffamily\Roman{page}}}}
\def\endpreface{\cleardoubleemptypage}
\newcommand*{\prefaceauthor}[2]{%
\bigskip\bigskip\noindent{{#1}\hfill \textit{#2}}}

\RequirePackage[scaled=0.96]{helvet}% for description environment
\RequirePackage{palatino}
\RequirePackage{mathpazo}
\RequirePackage{ifthen}
\RequirePackage{eso-pic}
\RequirePackage{multicol}
\RequirePackage{scrpage2}
\RequirePackage{afterpage}
\RequirePackage{relsize}
\RequirePackage[fleqn]{amsmath}

\setlength{\mathindent}{1em minus 1em}

\renewcommand*{\tableofcontents}{%
  \begingroup
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\hspace{39.5pt}\contentsname% => right
        \@mkboth{\contentsname}{\contentsname}}%
    \@parskipfalse\@parskip@indent%
    \if@tocleft\before@starttoc{toc}\fi%
    \@starttoc{toc}%
    \if@tocleft\after@starttoc{toc}\fi%
    \if@restonecol\twocolumn\fi
  \endgroup
}


\DeclareRobustCommand\bkseries{%
  \not@math@alphabet\bkseries\mathbk
  \fontseries{bk}\selectfont
}
\DeclareTextFontCommand\textbk{\bkseries\sffamily}
\DeclareTextFontCommand\textli{\liseries\sffamily}



\DeclareRobustCommand\bfseries{%
  \not@math@alphabet\bfseries\mathbf
  \fontseries{bx}\selectfont
}
\DeclareTextFontCommand\textbf{\bfseries}

\DeclareRobustCommand\liseries{%
  \not@math@alphabet\liseries\mathit
  \fontseries{l}\selectfont
}

\oddsidemargin=25mm
\evensidemargin=25mm

%%  Satzspiegel  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\textwidth=120mm
\textheight=193mm
\headsep=3.5mm
\topskip=5mm
\topmargin=15mm
\renewcommand\footnoterule{}
\renewcommand\deffootnote[4][]{%
  \long\def\@makefntext##1{%
    \setlength{\@tempdimc}{#3}%
    \def\@tempa{#1}\ifx\@tempa\@empty
      \@setpar{\@@par
        \@tempdima = \hsize
        \addtolength{\@tempdima}{-#2}
        \parshape \@ne #2 \@tempdima}%
    \else
      \addtolength{\@tempdimc}{#2}%
      \addtolength{\@tempdimc}{-#1}%
\newcommand\footfrac{.75}%%%
      \@setpar{\@@par
        \@tempdima = \footfrac\hsize
        \addtolength{\@tempdima}{-#1}
        \@tempdimb = \footfrac\hsize
        \addtolength{\@tempdimb}{-#2}
        \parshape \tw@ #1 \@tempdima #2 \@tempdimb}%
    \fi
    \par
    \parindent\@tempdimc\noindent
    \ftn@font\hbox to \z@{\hss\@@makefnmark}\RaggedRight ##1}
  \def\@@makefnmark{\hbox{\ftnm@font{#4}}}
}
\deffootnote[1.6em]{1.6em}{1em}
{\hbox{\sffamily{\bfseries\thefootnotemark}) }}
\deffootnotemark{\textsuperscript{\normalfont\thefootnotemark}}
\parskip=0ex
\xdef\@parindent{\the\parindent}

%%  Umbruch  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\clubpenalty=10000
\widowpenalty=10000

\usepackage{ragged2e}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%Titelseite

\if@titlepage
    \renewcommand*\maketitle[1][1]{\begin{titlepage}%
    \setcounter{page}{#1}
    \let\footnotesize\small
    \let\footnoterule\relax
    \let\footnote\thanks
    \renewcommand*\thefootnote{\@fnsymbol\c@footnote}%
    \let\@oldmakefnmark\@makefnmark
    \def\@makefnmark{\rlap\@oldmakefnmark}
    \ifx\@extratitle\@empty \else
        \noindent\@extratitle\next@tpage\cleardoublepage\thispagestyle{empty}
    \fi
    \ifx\@titlehead\@empty \else
        \noindent\begin{minipage}[t]{\textwidth}
        \@titlehead
        \end{minipage}\par
    \fi
    \null\vfill
    %\begin{center}%Li-b
    \ifx\@subject\@empty \else
        \noindent{\Large \@subject \par}
        \vskip 3em
    \fi
    \noindent{\sectfont\huge \@title\par}
    \vskip 3em
    {\Large \lineskip 0.75em
%    \begin{tabular}[t]{c}
        \noindent\@author
%    \end{tabular}%
\par}
    \vskip 1.5em
    {\Large \noindent\@date \par}
    \vskip \z@ \@plus3fill
    {\Large \@publishers \par}
    \vskip 3em
    %\end{center}%%Li-b
    \par
    \@thanks
    \vfill\null
    \if@twoside\next@tpage
        \noindent\begin{minipage}[t]{\textwidth}
        \@uppertitleback
        \end{minipage}\par
        \vfill
        \noindent\begin{minipage}[b]{\textwidth}
        \@lowertitleback
        \end{minipage}
    \fi
    \ifx\@dedication\@empty \else
        \next@tpage\null\vfill
        {\centering \Large \@dedication \par}
        \vskip \z@ \@plus3fill
        \if@twoside \next@tpage\cleardoublepage \fi
    \fi
    \end{titlepage}
    \setcounter{footnote}{0}%
    \global\let\thanks\relax
    \global\let\maketitle\relax
    \global\let\@thanks\@empty
    \global\let\@author\@empty
    \global\let\@date\@empty
    \global\let\@title\@empty
    \global\let\@extratitle\@empty
    \global\let\@titlehead\@empty
    \global\let\@subject\@empty
    \global\let\@publishers\@empty
    \global\let\@uppertitleback\@empty
    \global\let\@lowertitleback\@empty
    \global\let\@dedication\@empty
    \global\let\author\relax
    \global\let\title\relax
    \global\let\extratitle\relax
    \global\let\titlehead\relax
    \global\let\subject\relax
    \global\let\publishers\relax
    \global\let\uppertitleback\relax
    \global\let\lowertitleback\relax
    \global\let\dedication\relax
    \global\let\date\relax
    \global\let\and\relax}
\else
     \renewcommand*\maketitle[1][1]{\par
       \@tempcnta=#1\relax\ifnum\@tempcnta=1\else
         \ClassWarning{scrbook}
                      {Optional argument of \string\maketitle\space ignored
                       at\MessageBreak
                       notitlepage-mode}\fi
       \begingroup
         \renewcommand*\thefootnote{\@fnsymbol\c@footnote}%
         \let\@oldmakefnmark\@makefnmark
         \def\@makefnmark{\rlap\@oldmakefnmark}
         \if@twocolumn
           \ifnum \col@number=\@ne
             \@maketitle
           \else
             \twocolumn[\@maketitle]%
           \fi
         \else
           \newpage
           \global\@topnum\z@   % Prevents figures from going at top of page.
           \@maketitle
         \fi
         \thispagestyle{\titlepagestyle}\@thanks
       \endgroup
       \setcounter{footnote}{0}%
       \let\thanks\relax
       \let\maketitle\relax
       \let\@maketitle\relax
       \global\let\@thanks\@empty
       \global\let\@author\@empty
       \global\let\@date\@empty
       \global\let\@title\@empty
       \global\let\@extratitle\@empty
       \global\let\@titlehead\@empty
       \global\let\@subject\@empty
       \global\let\@publishers\@empty
       \global\let\@uppertitleback\@empty
       \global\let\@lowertitleback\@empty
       \global\let\@dedication\@empty
       \global\let\author\relax
       \global\let\title\relax
       \global\let\extratitle\relax
       \global\let\titlehead\relax
       \global\let\subject\relax
       \global\let\publishers\relax
       \global\let\uppertitleback\relax
       \global\let\lowertitleback\relax
       \global\let\dedication\relax
       \global\let\date\relax
       \global\let\and\relax}
\fi
\def\@maketitle{%
    \clearpage
    \let\footnote\thanks
    \ifx\@extratitle\@empty \else
        \noindent\@extratitle \next@tpage \if@twoside \null\next@tpage \fi
    \fi
    \ifx\@titlehead\@empty \else
        \noindent\begin{minipage}[t]{\textwidth}
        \@titlehead
        \end{minipage}\par
    \fi
    \null
    \vskip 2em%
    \begin{center}%
    \ifx\@subject\@empty \else
        {\Large \@subject \par}
        \vskip 1.5em
    \fi
    {\sectfont\huge \@title \par}%
    \vskip 1.5em%
    {\Large
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
    \vskip 1em%
    {\Large \@date \par}%
    \vskip \z@ \@plus 1em
    {\Large \@publishers \par}
    \ifx\@dedication\@empty \else
        \vskip 2em
        {\Large \@dedication \par}
    \fi
  \end{center}%
  \par
  \vskip 2em}




%%  Kolumnentitel  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\pagestyle{scrheadings}

\renewcommand\chapterpagestyle{scrheadings}

%%%%%%%%%%%%%%%%%%%%%%%%w-layout
%%  Kolumnentitel  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\clearscrheadings
\clearscrplain
\pagestyle{scrheadings}

\lehead[%
  \llap{%
    \pagemark
    \hspace{1mm}%
    \smash{\rule[-2.8mm]{1pt}{6mm}}%
    \hspace{2mm}%
  }%
]{%
  \llap{%
    \pagemark
    \hspace{1mm}%
    \smash{\rule[-2.8mm]{1pt}{6mm}}%
    \hspace{2mm}%
  }%
  {%
    \sffamily
    \itshape
    \selectfont
    \headmark
  }%
}

\rohead[%
  \rlap{%
    \hspace{2mm}%
    \smash{\rule[-2.8mm]{1pt}{6mm}}%
    \hspace{1mm}%
    \pagemark
  }%
]{%
  {%
      \sffamily
    \itshape
    \selectfont
    \headmark
  }%
  \rlap{%
    \hspace{2mm}%
    \smash{\rule[-2.8mm]{1pt}{6mm}}%
    \hspace{1mm}%
    \pagemark
  }%
}

\renewcommand\pnumfont{%
  \sffamily%
  \bfseries
  \upshape
  \fontsize{8}{12}%
  \selectfont
}

\renewcommand\headfont{%
  \sffamily%
  \itshape
  \fontsize{8.5}{12}%
  \selectfont
}

%%  Kapitel, Abschnitte usw.  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\part[1]{%
  \clearpage
  \ifodd\value{page}%
  \else
    \mbox{}%
    \thispagestyle{empty}%
    \clearpage
  \fi
  \refstepcounter{part}%
  \chapter*{Part~\arabic{part}\quad #1}%
  \thispagestyle{empty}\copyrightzeile%
  \addtocontents{toc}{%
    \protect\tocline
      {0}%
%      {Part~\arabic{part}\qquad#1\quad
      {Part~\arabic{part}\hspace{15.5pt}#1\quad
      {\sffamily\bfseries\itshape\arabic{page}}%
}%
      {}%
      {}%
  }%
}

\newcommand\numbered@chaptermark{
  \renewcommand\chaptermarkformat{%
    \thechapter
    \enskip
  }%
}

\newcommand\numbered@sectionmark{%
  \renewcommand\sectionmarkformat{%
    \thesection
    \enskip
  }%
}

\newcommand\unnumbered@chaptermark{
  \renewcommand\chaptermarkformat{}%
}

\newcommand\unnumbered@sectionmark{%
  \renewcommand\sectionmarkformat{}%
}

\numbered@chaptermark
\numbered@sectionmark

\renewcommand\sectfont{%
\sffamily%
  \bfseries
}

\renewcommand\chapter{\secdef\chapter@\chapter@s}

\newcommand\chapter@[2][]{%
\numbered@chaptermark
  \clearpage
  \ifodd\value{page}%
  \else
    \mbox{}%
    \thispagestyle{empty}%
    \clearpage
  \fi
 \refstepcounter{chapter}%
  \addtocontents{toc}{%
    \protect\tocline
      {0}%
      {\thechapter}%
      {#1}%
      {\sffamily\itshape\arabic{page}}
  }%
\chaptermark{#1}%
  \thispagestyle{scrplain}%
  \vspace*{26mm}%
  \noindent
  \smash{\parbox[b]{\textwidth}{%
    \sectfont
    \fontsize{12}{16}\selectfont
    \thechapter\\
    \fontsize{13}{16}\selectfont
    #2
  }}\copyrightzeile%
  \vskip2\baselineskip
  \@afterindentfalse
  \@afterheading
}

\newcommand\chapter@s[2][\relax]{%
  \clearpage
  \ifodd\value{page}%
  \else
    \mbox{}%
    \thispagestyle{empty}%
    \clearpage
  \fi
  \ifx#1\relax
  \else
    \unnumbered@chaptermark
    \addtocontents{toc}{%
      \protect\tocline
        {0}%
        {}%
        {#1}%
        {\sffamily\itshape\arabic{page}}%
    }%
    \markboth{#1}{#1}%
  \fi
 \thispagestyle{scrplain}%HHH
  \vspace*{31mm}%
  \noindent
  \smash{\parbox[b]{\textwidth}{%
    \sectfont
    \fontsize{13}{16}\selectfont
    #2
  }}%
  \vskip2\baselineskip
  \@afterindentfalse
  \@afterheading
}

\renewcommand\section{%
  \heading{section}%          Name
          {2\baselineskip}%   \vskip vor  Ueberschrift
          {\baselineskip}%    \vskip nach Ueberschrift
                         %    (negativ fuer Spitzmarke)
}

\renewcommand\subsection{%
  \heading{subsection}%
          {\baselineskip}%
          {\baselineskip}%
}

\renewcommand\subsubsection{%
  \heading{subsubsection}%
          {\baselineskip}%
          {6pt}%
}

\newcommand\heading@name{}
\newcommand\heading@vskip@above{}
\newcommand\heading@vskip@below{}

\newcommand\heading[3]{%
  \renewcommand\heading@name{#1}%
  \renewcommand\heading@vskip@above{#2}%
  \renewcommand\heading@vskip@below{#3}%
  \@afterindentfalse%--uk--% Suppresses indent in the first paragraph
  \secdef\heading@\heading@s
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand\tocline[4]{{%
%   #1 = Level (0 bis ...) (0=chapter, 1=section, etc.)
%   #2 = Nummer (Level ist die Anzahl Ziffern)
%   #3 = Name (oder Titel)
%   #4 = Seitenzahl
  \ifnum#1=0\relax
    \vskip1\baselineskip
    \fontsize{9.5}{12}%
    \bfseries
    \sffamily
  \fi\noindent
  \leavevmode
  \hbox to\tocnumwidth{#2}%
  \hspace{2mm}%
  \parbox[t]{106mm}{%
    \raggedright
    #3%
    \penalty10000
    \quad
    \penalty10000
    {%
      \ifnum#1=0\relax\else
        \fontsize{9}{12}%
      \fi
      \normalfont\itshape
      #4%
    }%
    \rule[-1.6mm]{0mm}{1mm}%
  }
  \par
}}

\newcommand\auline[1]{%
  \tocline
    {0}%
    {}%
    {\fontsize{8.75}{12}\sffamily\itshape#1}%
    {}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand\section@name{section}
\newcommand\subsection@name{subsection}
\newcommand\subsubsection@name{subsubsection}
\newcommand\paragraph@name{paragraph}

\newcommand\heading@[2][1]{%
  \vskip-\lastskip
  \refstepcounter{\heading@name}%
  \vskip\heading@vskip@above
  \noindent
\parbox{\textwidth}{
  {%
    \sectfont
    {\ifx\heading@name\subsection@name
      \mdseries
    \else\ifx\heading@name\subsubsection@name
      \mdseries
    \else\ifx\heading@name\paragraph@name
      \mdseries
    \fi\fi\fi
    \fontsize{9.5}{12}\selectfont
    \csname the\heading@name\endcsname}%%HerrKohm
\long\def\@tempa{subsubsection}%
\ifx\heading@name\@tempa\space\else\\\fi%
    \fontsize{9.5}{12}\selectfont
   ~#2
}}%
%%%%%%%%%%%%%%%%%%%%%%%%%%%
  \nopagebreak
  \ifdim\heading@vskip@below<0pt
    \hskip\heading@vskip@below
  \else
    \vskip\heading@vskip@below
  \fi
  \nopagebreak
  \@afterheading
    {\ifx\heading@name\section@name
      \addtocontents{toc}{%
        \protect\tocline
          {1}%
          {\csname the\heading@name\endcsname}%
          {#1}%
          {\thepage}%
      }%
    \else\ifx\heading@name\subsection@name
      \addtocontents{toc}{%
        \protect\tocline
          {2}%
          {\csname the\heading@name\endcsname}%
          {#1}%
          {\thepage}%
      }%
    \else\ifx\heading@name\subsubsection@name
% puts subsubsection into the table of contents (start)
      \addtocontents{toc}{%
        \protect\tocline
          {3}%
          {\csname the\heading@name\endcsname}%
          {#1}%
          {\thepage}%
      }%
% puts subsubsection into the table of contents (end)
    \else\ifx\heading@name\paragraph@name
      \addtocontents{toc}{%
        \protect\tocline
          {4}%
          {\csname the\heading@name\endcsname}%
          {#1}%
          {\thepage}%
      }%
    \fi\fi\fi\fi}
  \ifx\heading@name\section@name
    \numbered@sectionmark
    \sectionmark{#1}%
  \fi
}

\newcommand\heading@s[2][\relax]{%
  \vskip-\lastskip
  \vskip\heading@vskip@above
  \noindent
  {%
    \sectfont
    \fontsize{9.5}{12}\selectfont
    #2
  }%
  \nopagebreak
  \ifdim\heading@vskip@below<0pt
    \hskip\heading@vskip@below
  \else
    \vskip\heading@vskip@below
  \fi
  \nopagebreak
  \@afterheading
  \if#1\relax
  \else
    \addtocontents{toc}{%
      \protect\tocline
        {2}%
        {\csname the\heading@name\endcsname}%
        {#1}%
        {\thepage}%
    }%
    \if\heading@name\section@name
      \unnumbered@sectionmark
      \sectionmark{#1}%
    \fi
  \fi
}

\newif\ifParagraph
\newif\ifNumberedParagraph

\newcommand\useparagraphs{\Paragraphtrue}
\newcommand\numberparagraphs{\NumberedParagraphtrue}

\AtBeginDocument{
  \ifNumberedParagraph
    \Paragraphtrue
    \setcounter{secnumdepth}4
  \else
    \setcounter{secnumdepth}3
  \fi
  \ifParagraph
    \renewcommand\subsubsection{%
      \heading{subsubsection}%
              {\baselineskip}%
              {0.3\baselineskip}%
    }%
    \ifNumberedParagraph
      \renewcommand\paragraph{%
        \heading{paragraph}%
                {\baselineskip}%
                {-1em}%
      }%
    \else
      \renewcommand\paragraph{%
        \@startsection{paragraph}%
                      {4}%
                      {\z@}%
                      {\baselineskip}%
                      {-1em}%
                      {\fontsize{9.5}{12}\sectfont\selectfont}%
      }%
      \renewcommand\subparagraph{%
        \@startsection{subparagraph}%
                      {5}%
                      {\z@}%
                      {\baselineskip}%
                      {-1em}%
                      {\fontsize{9.5}{12}\sffamily\itshape\selectfont}%
      }%
    \fi
  \fi
}

\def\and{\unskip, }%

\def\orig@bibitem{}
\let\orig@bibitem\bibitem

\renewenvironment{thebibliography}[1]{%
\section*{\bibname}%
\markboth{\bibname}{\bibname}
    \addtocontents{toc}{%
      \protect\tocline
        {1}%
        {}%
        {\bibname}%
        {\arabic{page}}}%
\vspace{-5mm}\noindent%
\RaggedRight%
  \begin{multicols}{2}
    \setcounter{enumiv}{0}%
     \renewcommand\bibitem[2][]{%
      \refstepcounter{enumiv}%
      \par\vspace{3pt plus 3pt minus 2pt}
      \raggedcolumns
       \noindent%
       {%
         \let\item=\relax
         \def\@listctr{enumiv}%
         \orig@bibitem{##2}%
       }%
       \hangafter1
       \hangindent\bibindent
       \hbox to\bibindent{%
         \fontsize{8}{10}%
 \sffamily%
         \bfseries
         \hfill
         \arabic{enumiv}%
         \hspace*{1mm}%
       }%
       \ignorespaces
     }%
      \normalfont
      \fontfamily{ppl}%
      \fontsize{8}{10}%
      \selectfont
%      #1%
}{%
  \end{multicols}
}

\newenvironment{Thebibliography}[1]{%
\chapter*[\bibname]{\rule{\bibindent}{0mm}\fontsize{13}{16}\selectfont\bibname}%
\markboth{\bibname}{\bibname}\copyrightzeile
\vspace{-4mm}\noindent%
\RaggedRight%
  \begin{multicols}2
    \setcounter{enumiv}0%
    \renewcommand\bibitem[2][]{%
      \refstepcounter{enumiv}%
      \par\vspace{3pt plus 3pt minus 2pt}
      \raggedcolumns
      \noindent%
      {%
        \let\item=\relax
        \def\@listctr{enumiv}%
        \orig@bibitem{##2}%
      }%
      \hangafter1
      \hangindent\bibindent
      \hbox to\bibindent{%
      \fontsize{8}{10}%
\sffamily%
        \bfseries
        \hfill
        \arabic{enumiv}%
        \hspace*{1mm}%
      }%
      \ignorespaces
    }%
      \normalfont
      \fontfamily{ppl}%
      \fontsize{8}{10}%
      \selectfont
      #1%
}{%
  \end{multicols}
}


%%  Tabellen  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\fps@table{tbp}

\renewcommand\capfont{%
  \normalfont
  \fontsize{8.5}{10}%
  \sffamily
  \RaggedRight
}

\renewcommand\caplabelfont{%
  \normalfont
  \fontsize{8.5}{10}%
  \sffamily
  \bfseries
}

\setcapindent{0mm}

\newcommand\orig@tabular{}
\let\orig@tabular\tabular
\newcommand\orig@endtabular{}
\let\orig@endtabular\endtabular

\newcommand\orig@cr{}%

\newdimen\saved@arrayrulewidth

\def\set@rules#1{\noalign{\global\arrayrulewidth=#1}}

\def\save@rules#1{%
  \noalign{\global\saved@arrayrulewidth=\arrayrulewidth}%
  \set@rules{#1}%
}%

\def\restore@rules{\set@rules{\saved@arrayrulewidth}}

\def\head@rule@width{1pt}
\def\comb@rule@width{2pt}
\def\comb@rule@length{6.5mm}

\newcommand\orig@hline{}
\let\orig@hline=\hline

\newdimen\orig@arrayrulewidth
\orig@arrayrulewidth=\arrayrulewidth

\def\hline{%
  \save@rules{\orig@arrayrulewidth}%
  \noalign{\vskip.5pt}%
  \orig@hline
  \noalign{\vskip.5pt}%
  \restore@rules
}

\newcommand\tfnm[1]{%                % = tabular foot note mark
 % {\fontsize{7.5}{9.5}\normalfont#1)}%
 \raise1.5mm\hbox {\fontsize{5}{9.5}\normalfont\bfseries#1)}%
}%

\newcommand\tfnt[2]{%                % = tabular foot note text
  \if@beginning\vskip-3mm\fi
  \fontsize{7.5}{9.5}\normalfont
  \hbox{%
    %\hbox to5mm{\fontfamily{scslfrg}\bfseries#1)}%
    \hbox to5mm{\sffamily\bfseries#1)}%
    \parbox[t]{75mm}{\RaggedRight{#2}}%
  }%
  \vskip3mm
  \mark@beginning
}

\newcommand\thf[1]{%                 % = tabular head font
  {\normalfont\sffamily\bfseries#1}%
}%


\def\orig@table{}
\let\orig@table=\table
\renewcommand\table[1][htbp]{%
  \orig@table[#1]
  \normalfont
  \fontfamily{ppl}%
  \fontsize{8}{10.5}%
  \selectfont
  \belowcaptionskip=5mm\relax
}

%%  Inhaltsverzeichnis  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\@pnumwidth{6mm}% Platz fuer Seitenzahlen
\def\@dotsep{1.8}%    Abstand der Puenktchen (in "math units")

\renewcommand\thf[1]{%                 % = tabular head font
  {\normalfont\sffamily\bfseries#1}%
}%



%%%%%%%%%%%%%%%%%%%
\unitlength=.33333333333333333333mm
\newcommand{\copyrighttext}{}
\newcommand\copyrightzeile[1][-40]{%Abstand v.unten
  \ifodd\count0
    \copyrightzeileII{145}{#1}%
  \else
    \copyrightzeileII{145}{#1}%
  \fi
}
%%%%%%%%%%%%%%%%%%%
\newcommand\copyrightzeileII[2]{{%
  \unitlength1mm\relax
  \AddToShipoutPicture*{%
    \put(#1,#2){\parbox{\textwidth}{\normalfont\footnotesize
\copyrighttext
    }}%
  }%
}}



\renewcommand\chapterformat{\textbf{\thechapter}\vskip-2mm}

\renewcommand\chapappifprefix[1][]{}

\newcommand\Chapter[2]{%
  \refstepcounter{chapter}%
  \chapter*{%
    \parbox[b]{31mm}{%
      \textbf{{\fontsize{26}{10}\selectfont\thechapter}
      \\#1}%
    }%
    \hspace{3.5mm}%
    \parbox[t]{65.5mm}{%
      %\liseries
      \mdseries
      \raggedright
      \small
      #2%
    }%
  }%
\copyrightzeile%
  \addcontentsline{toc}{chapter}{%
    \protect\numberline{\textsf{\thechapter\protect\\#1}%
    %\ifx#2\relax\relax\else\protect\\\mdseries#2\fi
    }%HHH
  }%
  \chaptermark{#1}%
  \sectionmark{#1}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand\CHAPTER[1]{%
  \refstepcounter{chapter}%
  \chapter*{%
    \parbox[b]{\textwidth}{%
      \textbf{{\fontsize{26}{10}\selectfont\thechapter}
      \\#1}%
    }%
  }%
\copyrightzeile%
  \addcontentsline{toc}{chapter}{%
    \protect\numberline{\textsf{\thechapter\protect\\#1}%
    }%HHH
  }%
  \chaptermark{#1}%
  \sectionmark{#1}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%  Schriftgroessen  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\normalsize{%
  \@setfontsize\normalsize\@xpt{12.9pt}%
  \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
  \abovedisplayshortskip \z@ \@plus3\p@
  \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
  \belowdisplayskip \abovedisplayskip
  \let\@listi\@listI}

\normalsize

\renewcommand\small{%
  \@setfontsize\small\@ixpt{10}%
  \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus2\p@
  \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
              \topsep 4\p@ \@plus2\p@ \@minus2\p@
              \parsep 2\p@ \@plus\p@ \@minus\p@
              \itemsep \parsep}%
  \belowdisplayskip \abovedisplayskip}

\renewcommand\footnotesize{%
  \@setfontsize\footnotesize\@viiipt{9.5}%
  \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus\p@
  \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
              \topsep 3\p@ \@plus\p@ \@minus\p@
              \parsep 2\p@ \@plus\p@ \@minus\p@
              \itemsep \parsep}%
  \belowdisplayskip \abovedisplayskip}

\renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
\renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\renewcommand\large{\@setfontsize\large{12.5}{16}}
%\newcommand\Large{\@setfontsize\Large\@xivpt{18}}
%\newcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}
%\newcommand\huge{\@setfontsize\huge\@xxpt{25}}
%\newcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}

\renewcommand\size@section{\normalsize}
\renewcommand\size@chapter{\large}

%%  Abbildungen  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\floatpagefraction{1}
\def\topfraction{1}
\def\bottomfraction{1}
\def\textfraction{0}

\newcommand\figgap{5mm}
%% \newcommand\capstyle{\mdseries\upshape\sffamily\small\RaggedRight}
%\newcommand\capstyle{\mdseries\upshape\sffamily\footnotesize\RaggedRight}
\newcommand\capstyle{\capfont\RaggedRight}
\newcommand\capfrac{.75}

\newcommand\Caption[1]{%
  \refstepcounter{figure}%
  \par\parbox[t]{\capfrac\textwidth}{%
    \capstyle
    {\caplabelfont \figurename~\thefigure~}~#1%
  }%
}

\newcommand\Captiontwo[1]{%
  \refstepcounter{figure}%
  \\[-4mm]
  \parbox{\capfrac\textwidth}{\begin{multicols}{2}%
    \capstyle
    {\caplabelfont \figurename~\thefigure~}~#1%
  \end{multicols}}%
\vspace*{-6mm}
}


\renewcommand\caption[1]{%
  \refstepcounter{table}%
  \parbox{\textwidth}{%
    \capstyle
    {\caplabelfont \tablename~\thetable~}~#1%
  }%
\vskip3mm
}

\newenvironment{biographie}[2][\relax]{%
  \begin{figure}
    \smash{\rule{\textwidth}{\fboxrule}}%
     \vspace{-.5mm}\par
    \ifx#1\relax
      \begin{multicols}2
    \else
      \begin{multicols}3
        \vspace*{-2mm}
        \includegraphics[width=\hsize]{#1}%
        \newpage
    \fi
    \capstyle
    \textrm{\textbf{#2}}
    \mdseries\sffamily
}{%
      \end{multicols}%
    \vskip-6.5mm
    \smash{\rule{\textwidth}{\fboxrule}}%
  \end{figure}
}


%%  Verschiedenes %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\usepackage{endnotes}
\usepackage{xspace}
\usepackage{multicol}

\newcommand\zB{z.\,B.}

\newcommand\letter[1]{\item{\sffamily\bfseries{\textit{#1}}}\nopagebreak}
\renewenvironment{theindex}
  {\if@twocolumn
    \@restonecolfalse
    \else
    \@restonecoltrue
    \fi
    \columnseprule \z@
    \columnsep 35\p@
\chapter*{\indexname}
\thispagestyle{\indexpagestyle}\index@preamble
  \begin{multicols}{2}\@mkboth{\indexname}{\indexname}
    \parindent\z@\copyrightzeile\RaggedRight\raggedcolumns
    \parskip.2\p@ \@plus .3\p@\relax
        \def\@idxitem{\par\hangindent 6pt}%
        \def\subitem{\@idxitem --\ }%
        \def\subsubitem{\@idxitem --\ --\ }%
                 \let\item\@idxitem \ignorespaces}%
  {\end{multicols}\if@restonecol\onecolumn\else\clearpage\fi}

%%%%%%%%%%%%%%%%%%%%2-spaltige Fussnoten
\newcommand*\lastfootnotestart{}
\newcommand*\savefootnote{}

\AtBeginDocument{\xdef\lastfootnotestart{0}}
\newcommand\pagefootnotes[1]{%
  \@bsphack
  \insert\footins{%
    \parindent=0pt
    \xdef\savefootnote{\the\c@footnote}%
    \setcounter{footnote}{\lastfootnotestart}%
    \vspace{-4.8mm}%
    \begin{multicols}2%
      #1
    \end{multicols}%
    \xdef\lastfootnotestart{\the\c@footnote}%
    \setcounter{footnote}{\savefootnote}%
  }%
  \@esphack
}

\renewcommand\footnotetext[1]{%
  \stepcounter{footnote}%
  \setlength\parindent{4mm}% ( 1mm + 3mm )
  \addtolength\parindent{1em}%
  \@hangfrom{%
    \makebox[3mm][r]{%
\footnotesize\sffamily{\bfseries
      \thefootnote)}%
    }%
    \hspace{1mm}%
  }{%
    \fontsize{8}{9.5}%
    \selectfont
    \RaggedRight
    #1
    \par
  }\par
  \ignorespaces
}

\newcommand{\footnotetwocol}[2]{%
\footnotemark[#1]\pagefootnotes{%
\setcounter{footnote}{#1}%
\addtocounter{footnote}{-1}%
\footnotetext{#2}}%
\refstepcounter{footnote}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand*{\chapterauthor}[2][****]{%
\ifthenelse{\equal{#1}{****}}%
{\ifthenelse{\equal{#2}{}}{}{\addtocontents{toc}{\protect\tocline{2}{}{\itshape #2}{}}%
{\vskip-24pt\textit{#2}\vskip24pt\@afterindentfalse\@afterheading}}}%
% else
{\ifthenelse{\equal{#1}{}}{}{\addtocontents{toc}{\protect\tocline{2}{}{\itshape #1}{}}}%
\ifthenelse{\equal{#2}{}}{}{{\vskip-24pt\textit{#2}\vskip24pt\@afterindentfalse\@afterheading}}}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%% Anmerkungen %%%%%%%%%%%%%%

\renewcommand{\theendnotes}{\immediate\closeout\@enotes
\global\@enotesopenfalse
  \begingroup
    \makeatletter
    \edef\@tempa{`\string >}%
    \ifnum\catcode\@tempa=12%
      \let\@ResetGT\relax
    \else
      \edef\@ResetGT{\noexpand\catcode\@tempa=\the\catcode\@tempa}%
      \@makeother\>%
    \fi
    \def\@doanenote##1##2>{\def\@theenmark{##1}\par\begingroup
        \@ResetGT
        \edef\@currentlabel{\csname p@endnote\endcsname\@theenmark}%
        \enoteformat}
    \def\@endanenote{\par\endgroup}%
    \enoteheading
    \enotesize
\begin{multicols}{2}
    \input{\jobname.ent}%
\end{multicols}
\endgroup}



\def\enoteheading{%
  \chapter*{\notesname}%
  \chaptermark{\notesname}%
  \sectionmark{\notesname}%
    \addtocontents{toc}{%
      \protect\tocline
        {0}%
        {}%
        {\notesname}%
        {\sffamily\arabic{page}}%
    }%
\indent
}

\def\enoteformat{%
  \rightskip=0pt
  \leftskip =0pt
  \leavevmode
  \llap{\hbox to\parindent{\sffamily{\bfseries\theenmark}) }}%
}

\def\enotesize{\footnotesize}


\renewenvironment{quote}
               {\list{}{\rightmargin\leftmargin}%
\item\relax\advance\hsize by-\leftmargin}
               {\endlist}

%%%%%%%%%%%%%%%%%%%%%%%%%Literatur%%%%%%%%%%%%%%%%%%%%%%
%\makeatletter
\def\@biblabel#1{\textsf{\textbf{#1}}}
%\makeatother

%% For the List of Contributors
\newenvironment{contributor}[2][]
{\begin{minipage}[b]{\linewidth}{\sffamily\bfseries\itshape#2}{\sffamily\itshape\hfill#1}\par\small\smallskip}
%{\end{minipage}\vspace{9pt plus 2pt minus 2pt}}
{\end{minipage}\vspace{14pt plus 2pt minus 2pt}}

\useparagraphs

\endinput
%% End of `format170x240multiauthor.cls'
